@@ -60,6 +60,11 @@ test_that("lefser and lefserPlot work", {
     
     plt <- lefserPlot(results2)
     expect_s3_class(plt, "ggplot")
+    
+    expect_error(
+        lefserPlot(results2, label.font.face = "invalid"),
+        "'arg' should be one of"
+    )
 })
 
 test_that("no significant results behaviors are consistent", {
